==> cdktf-0.9.0.dev6.tar.gz: package/lib/backends/swift-backend.d.ts <==
import { Construct } from "constructs";
import { TerraformBackend } from "../terraform-backend";
import { TerraformRemoteState, DataTerraformRemoteStateConfig } from "../terraform-remote-state";
/**
 * @experimental
 */
export declare class SwiftBackend extends TerraformBackend {
    private readonly props;
    /**
     * @experimental
     */
    constructor(scope: Construct, props: SwiftBackendProps);
    /**
     * @experimental
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
/**
 * @experimental
 */
export declare class DataTerraformRemoteStateSwift extends TerraformRemoteState {
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, config: DataTerraformRemoteStateSwiftConfig);
}
/**
 * @experimental
 */
export interface SwiftBackendProps {
    /**
     * @experimental
     */
    readonly authUrl?: string;
    /**
     * @experimental
     */
    readonly cloud?: string;
    /**
     * @experimental
     */
    readonly container: string;
    /**
     * @experimental
     */
    readonly stateName?: string;
    /**
     * @experimental
     */
    readonly userName?: string;
    /**
     * @experimental
     */
    readonly userId?: string;
    /**
     * @experimental
     */
    readonly password?: string;
    /**
     * @experimental
     */
    readonly applicationCredentialId?: string;
    /**
     * @experimental
     */
    readonly applicationCredentialName?: string;
    /**
     * @experimental
     */
    readonly applicationCredentialSecret?: string;
    /**
     * @experimental
     */
    readonly token?: string;
    /**
     * @experimental
     */
    readonly regionName?: string;
    /**
     * @experimental
     */
    readonly tenantId?: string;
    /**
     * @experimental
     */
    readonly tenantName?: string;
    /**
     * @experimental
     */
    readonly domainId?: string;
    /**
     * @experimental
     */
    readonly domainName?: string;
    /**
     * @experimental
     */
    readonly userDomainName?: string;
    /**
     * @experimental
     */
    readonly userDomainId?: string;
    /**
     * @experimental
     */
    readonly projectDomainName?: string;
    /**
     * @experimental
     */
    readonly projectDomainId?: string;
    /**
     * @experimental
     */
    readonly defaultDomain?: string;
    /**
     * @experimental
     */
    readonly insecure?: boolean;
    /**
     * @experimental
     */
    readonly cacertFile?: string;
    /**
     * @experimental
     */
    readonly cert?: string;
    /**
     * @experimental
     */
    readonly key?: string;
    /**
     * @experimental
     */
    readonly archiveContainer?: string;
    /**
     * @experimental
     */
    readonly expireAfter?: string;
}
/**
 * @experimental
 */
export interface DataTerraformRemoteStateSwiftConfig extends DataTerraformRemoteStateConfig, SwiftBackendProps {
}

==> cdktf-0.11.0.dev4.tar.gz: package/lib/backends/swift-backend.d.ts <==
import { Construct } from "constructs";
import { TerraformBackend } from "../terraform-backend";
import { TerraformRemoteState, DataTerraformRemoteStateConfig } from "../terraform-remote-state";
export declare class SwiftBackend extends TerraformBackend {
    private readonly props;
    constructor(scope: Construct, props: SwiftBackendProps);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    getRemoteStateDataSource(scope: Construct, name: string, _fromStack: string): TerraformRemoteState;
}
export declare class DataTerraformRemoteStateSwift extends TerraformRemoteState {
    constructor(scope: Construct, id: string, config: DataTerraformRemoteStateSwiftConfig);
}
export interface SwiftBackendProps {
    readonly authUrl?: string;
    readonly cloud?: string;
    readonly container: string;
    readonly stateName?: string;
    readonly userName?: string;
    readonly userId?: string;
    readonly password?: string;
    readonly applicationCredentialId?: string;
    readonly applicationCredentialName?: string;
    readonly applicationCredentialSecret?: string;
    readonly token?: string;
    readonly regionName?: string;
    readonly tenantId?: string;
    readonly tenantName?: string;
    readonly domainId?: string;
    readonly domainName?: string;
    readonly userDomainName?: string;
    readonly userDomainId?: string;
    readonly projectDomainName?: string;
    readonly projectDomainId?: string;
    readonly defaultDomain?: string;
    readonly insecure?: boolean;
    readonly cacertFile?: string;
    readonly cert?: string;
    readonly key?: string;
    readonly archiveContainer?: string;
    readonly expireAfter?: string;
}
export interface DataTerraformRemoteStateSwiftConfig extends DataTerraformRemoteStateConfig, SwiftBackendProps {
}
